==> ukelli-ui-3.0.0.tgz: package/core/modal/modal-helper.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { Component } from 'react';
var ModalHelper = /** @class */ (function (_super) {
    __extends(ModalHelper, _super);
    function ModalHelper(props) {
        var _this = _super.call(this, props) || this;
        _this.showModal = function () {
            _this.setState(function (_a) {
                var modalSetting = _a.modalSetting;
                return ({
                    modalSetting: __assign({}, modalSetting, { isOpen: true })
                });
            });
        };
        _this.setModal = function (nextSetting) {
            _this.setState(function (_a) {
                var modalSetting = _a.modalSetting;
                var _b = nextSetting.isOpen, isOpen = _b === void 0 ? true : _b;
                return {
                    modalSetting: Object.assign({}, modalSetting, nextSetting, {
                        isOpen: isOpen
                    })
                };
            });
        };
        _this.closeModal = function () {
            var modalSetting = _this.state.modalSetting;
            _this.setState({
                modalSetting: __assign({}, modalSetting, { isOpen: false })
            });
        };
        _this.state = {
            modalSetting: {
                title: '',
                isOpen: false,
                children: '',
                id: ''
            }
        };
        return _this;
    }
    return ModalHelper;
}(Component));
export default ModalHelper;

==> ukelli-ui-3.3.1.tgz: package/core/modal/modal-helper.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { Component } from 'react';
var ModalHelper = /** @class */ (function (_super) {
    __extends(ModalHelper, _super);
    function ModalHelper(props) {
        var _this = _super.call(this, props) || this;
        _this.showModal = function () {
            _this.setState(function (_a) {
                var modalSetting = _a.modalSetting;
                return ({
                    modalSetting: __assign(__assign({}, modalSetting), { isOpen: true })
                });
            });
        };
        _this.setModal = function (nextSetting) {
            _this.setState(function (_a) {
                var modalSetting = _a.modalSetting;
                var _b = nextSetting.isOpen, isOpen = _b === void 0 ? true : _b;
                return {
                    modalSetting: Object.assign({}, modalSetting, nextSetting, {
                        isOpen: isOpen
                    })
                };
            });
        };
        _this.closeModal = function () {
            var modalSetting = _this.state.modalSetting;
            _this.setState({
                modalSetting: __assign(__assign({}, modalSetting), { isOpen: false })
            });
        };
        _this.state = {
            modalSetting: {
                title: '',
                isOpen: false,
                children: '',
                id: ''
            }
        };
        return _this;
    }
    return ModalHelper;
}(Component));
export default ModalHelper;
